altfire_authenticator library
altfire_authenticator with FlutterFire Authentication.
Classes
- AuthCredential
- Interface that represents the credentials returned by an auth provider. Implementations specify the details about each auth provider's credential requirements.
- Authenticator
-
Authenticator is a wrapper class for
FirebaseAuth. - OAuthCredential
- A generic OAuth credential.
- OAuthProvider
- A generic provider instance.
- PhoneAuthProvider
- This class should be used to either create a new Phone credential with an verification ID and SMS code.
- User
- A user account.
- UserCredential
-
A UserCredential is returned from authentication requests such as
createUserWithEmailAndPassword.
Enums
- SigningMethod
- Enum class for identifying the method of authentication.
Extensions
- UserExtension on User
- Extension methods for the User class.
Exceptions / Errors
- AuthCancelled
- Error class indicating that authentication was cancelled.
- AuthCredentialAlreadyInUse
- Error class indicating that the credential is already in use.
- AuthException
- Error class for identifying errors that occur during authentication. Generated from FirebaseAuthException.
- AuthFailedNetworkRequest
- Error class indicating that the network request failed.
- AuthInvalidPhoneNumber
- Error class indicating that the phone number is invalid.
- AuthRequiresRecentSignIn
- Error class indicating that recent sign-in is required.
- AuthRequiresSignIn
- Error class indicating that sign-in is required.
- AuthUndefinedError
- Error class indicating an undefined error.